@@ -1,7 +1,7 @@
 /*
  * The SIP module interface.
  *
- * Copyright (c) 2021 Riverbank Computing Limited <info@riverbankcomputing.com>
+ * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
  *
  * This file is part of SIP.
  *
@@ -24,8 +24,17 @@
 #include <Python.h>
 
 /* Sanity check on the Python version. */
-#if PY_VERSION_HEX < 0x03060000
-#error "This version of PyQt6.sip requires Python v3.6 or later"
+#if PY_VERSION_HEX < 0x03070000
+#error "This version of PyQt6.sip requires Python v3.7 or later"
+#endif
+
+
+#ifdef __cplusplus
+#include <exception>
+
+typedef bool (*sipExceptionHandler)(std::exception_ptr);
+#else
+typedef void *sipExceptionHandler;
 #endif
 
 
@@ -34,24 +43,39 @@ extern "C" {
 #endif
 
 
-/* The patch version of this implementation of the ABI. */
-#define SIP_MODULE_PATCH_VERSION    1
+/* The version of the ABI. */
+#define SIP_ABI_MAJOR_VERSION       13
+#define SIP_ABI_MINOR_VERSION       5
+#define SIP_MODULE_PATCH_VERSION    0
 
 
 /*
- * The changes to this version of the ABI.
+ * The change history of the ABI.
  *
- * This is the first minor version of this version of the ABI.
+ * v13.5
+ *  - Added the '#' conversion character to the argument parsers.
+ *
+ * v13.4
+ *  - The enum implementation now supports missing members.
+ *  - Published the 'array' type.
+ *  - Added the ctd_sizeof, ctd_array_delete members to sipClassTypeDef.
+ *  - Added the '>' conversion character to the argument parsers.
+ *
+ * v13.3
+ *  - Python v3.7 or later is required.
+ *
+ * v13.2
+ *  - Added support for SIP_ENUM_UINT_ENUM to represent IntEnums with unsigned
+ *    members.
+ *
+ * v13.1
+ *  - Added sipNextExceptionHandler().
  */
 
 
-/* The ABI version implemented. */
-#define SIP_ABI_MAJOR_VERSION       13
-#define SIP_ABI_MINOR_VERSION       0
-
 /* The version of the code generator. */
-#define SIP_VERSION                 0x60001
-#define SIP_VERSION_STR             "6.0.1"
+#define SIP_VERSION                 0x60708
+#define SIP_VERSION_STR             "6.7.8"
 
 /* These are all dependent on the user-specified name of the sip module. */
 #define _SIP_MODULE_FQ_NAME         "PyQt6.sip"
@@ -221,6 +245,7 @@ typedef int (*sipVirtHandlerFunc)(sip_gilstate_t, sipVirtErrorHandlerFunc,
         sipSimpleWrapper *, PyObject *, ...);
 typedef void (*sipAssignFunc)(void *, Py_ssize_t, void *);
 typedef void *(*sipArrayFunc)(Py_ssize_t);
+typedef void (*sipArrayDeleteFunc)(void *);
 typedef void *(*sipCopyFunc)(const void *, Py_ssize_t);
 typedef void (*sipReleaseFunc)(void *, int);
 typedef void (*sipReleaseUSFunc)(void *, int, void *);
@@ -805,6 +830,12 @@ typedef struct _sipClassTypeDef {
 
     /* The mixin initialisation function. */
     initproc ctd_init_mixin;
+
+    /* The optional array delete function. */
+    sipArrayDeleteFunc ctd_array_delete;
+
+    /* The sizeof the class. */
+    size_t ctd_sizeof;
 } sipClassTypeDef;
 
 
@@ -1021,6 +1052,9 @@ typedef struct _sipExportedModuleDef {
 
     /* The list of delayed dtors. */
     sipDelayedDtor *em_ddlist;
+
+    /* The exception handler. */
+    sipExceptionHandler em_exception_handler;
 } sipExportedModuleDef;
 
 
@@ -1319,11 +1353,11 @@ typedef struct _sipAPIDef {
     void (*api_visit_wrappers)(sipWrapperVisitorFunc visitor, void *closure);
     int (*api_register_exit_notifier)(PyMethodDef *md);
     int (*api_is_enum_flag)(PyObject *o);
-    void (*unused_public_1)();
-    void (*unused_public_2)();
-    void (*unused_public_3)();
-    void (*unused_public_4)();
-    void (*unused_public_5)();
+    void (*unused_public_1)(void);
+    void (*unused_public_2)(void);
+    void (*unused_public_3)(void);
+    void (*unused_public_4)(void);
+    void (*unused_public_5)(void);
 
     /*
      * The following are not part of the public API.
@@ -1387,11 +1421,11 @@ typedef struct _sipAPIDef {
     void (*api_instance_destroyed_ex)(sipSimpleWrapper **sipSelfp);
     PyObject *(*api_is_py_method_12_8)(sip_gilstate_t *gil, char *pymc,
             sipSimpleWrapper **sipSelfp, const char *cname, const char *mname);
-    void (*unused_private_1)();
-    void (*unused_private_2)();
-    void (*unused_private_3)();
-    void (*unused_private_4)();
-    void (*unused_private_5)();
+    sipExceptionHandler (*api_next_exception_handler)(void **statep);
+    void (*unused_private_2)(void);
+    void (*unused_private_3)(void);
+    void (*unused_private_4)(void);
+    void (*unused_private_5)(void);
 } sipAPIDef;
 
 const sipAPIDef *sip_init_library(PyObject *mod_dict);
@@ -1406,8 +1440,7 @@ const sipAPIDef *sip_init_library(PyObject *mod_dict);
 
 
 /*
- * These are flags that can be passed to sipConvertToArray().  These are held
- * in sw_flags.
+ * These are flags that can be passed to sipConvertToArray().
  */
 #define SIP_READ_ONLY       0x01    /* The array is read-only. */
 #define SIP_OWNS_MEMORY     0x02    /* The array owns its memory. */
@@ -1483,6 +1516,7 @@ const sipAPIDef *sip_init_library(PyObject *mod_dict);
 #define SIP_ENUM_FLAG       1       /* The base type is Flag. */
 #define SIP_ENUM_INT_ENUM   2       /* The base type is IntEnum. */
 #define SIP_ENUM_INT_FLAG   3       /* The base type is IntFlag. */
+#define SIP_ENUM_UINT_ENUM  4       /* The base type is IntEnum with unsigned members. */
 
 
 /*
